@@ -1,16 +1,17 @@
 package Evo::Class::Meta;
-use Evo '/::Const *';
 use Evo 'Carp croak; Scalar::Util reftype; -Lib strict_opts; -Internal::Util; Module::Load ()';
+use Evo '/::Attrs *';
+
 
 our @CARP_NOT = qw(Evo::Class);
 
-sub register ($me, $package, $attrs_class) {
+sub register ($me, $package) {
   my $self = Evo::Internal::Util::pkg_stash($package, $me);
   return $self if $self;
   $self = bless {
     package    => $package,
     private    => {},
-    attrs      => $attrs_class->new,
+    attrs      => Evo::Class::Attrs->new,
     methods    => {},
     reqs       => {},
     overridden => {}
@@ -104,7 +105,7 @@ sub reg_method ($self, $name) {
 }
 
 sub _public_attrs_slots($self) {
-  grep { !$self->is_private($_->[I_NAME]) } $self->attrs->slots;
+  grep { !$self->is_private($_->{name}) } $self->attrs->slots;
 }
 
 sub _public_methods_map($self) {
@@ -115,7 +116,7 @@ sub _public_methods_map($self) {
 }
 
 sub public_attrs($self) {
-  map { $_->[I_NAME] } $self->_public_attrs_slots;
+  map { $_->{name} } $self->_public_attrs_slots;
 }
 
 sub public_methods($self) {
@@ -137,10 +138,9 @@ sub extend_with ($self, $source_p) {
   foreach my $name (keys %reqs) { $self->reg_requirement($name); }
 
   foreach my $slot ($source->_public_attrs_slots) {
-    my ($name, @opts) = @$slot;
-    next if $self->is_overridden($name);
-    $self->reg_attr($name, @opts);
-    push @new_attrs, $name;
+    next if $self->is_overridden($slot->{name});
+    $self->reg_attr(@$slot{qw(name type value check ro inject)});
+    push @new_attrs, $slot->{name};
   }
 
   foreach my $name (keys %methods) {
@@ -185,7 +185,7 @@ sub check_implementation ($self, $inter_class) {
 # check?
 # is_ro?
 
-my @KNOWN_HAS = qw(default required lazy check is);
+my @KNOWN_HAS = qw(default required lazy check is inject);
 
 sub parse_attr ($me, @attr) {
   my %unknown = my %opts = (@attr % 2 ? (default => @attr) : @attr);
@@ -201,14 +201,14 @@ sub parse_attr ($me, @attr) {
     croak qq#"default" should be either a code reference or a scalar value#
       if ref($opts{default}) && (reftype($opts{default}) // '') ne 'CODE';
     ++$seen;
-    $type = ref($opts{default}) ? A_DEFAULT_CODE : A_DEFAULT;
+    $type = ref($opts{default}) ? ECA_DEFAULT_CODE : ECA_DEFAULT;
     $value = $opts{default};
   }
-  do { ++$seen; $type = A_REQUIRED; $value = $opts{required}; } if $opts{required};
+  do { ++$seen; $type = ECA_REQUIRED; } if $opts{required};
   if (exists $opts{lazy}) {
     croak qq#"lazy" should be a code reference# if (reftype($opts{lazy}) // '') ne 'CODE';
     ++$seen;
-    $type  = A_LAZY;
+    $type  = ECA_LAZY;
     $value = $opts{lazy};
   }
   croak qq{providing more than one of "default", "lazy", "required" doesn't make sense}
@@ -222,9 +222,9 @@ sub parse_attr ($me, @attr) {
 
   $ro = $is eq 'ro' ? 1 : 0;
   $check = $opts{check} if exists $opts{check};
-  $type ||= A_RELAXED;
+  $type ||= ECA_SIMPLE;
 
-  return ($type, $value, $check, $ro);
+  return ($type, $value, $check, $ro, $opts{inject});
 }
 
 sub info($self) {
@@ -255,7 +255,7 @@ Evo::Class::Meta
 
 =head1 VERSION
 
-version 0.0242
+version 0.0243
 
 =head1 METHODS
 
